@@ -13,7 +13,7 @@ def set_span_attribute(span: Span, name: str, value: Any):
 
 
 class TraceScorerConfig(BaseModel):
-    scorer: TraceAPIScorerConfig
+    scorer: TraceAPIScorerConfig | None
     model: Optional[str] = None
     sampling_rate: float = 1.0
     run_condition: Optional[Callable[..., bool]] = None
